@@ -1,4 +1,4 @@
-pub use subcrate_b::TEST_VALUE;
+pub const TEST_VALUE: u8 = 5u8;
 
 #[cfg(test)]
 mod tests {
